.. SPDX-FileCopyrightText: 2022 Contributors to the rez project
..
.. SPDX-License-Identifier: Apache-2.0

===
API
===

.. warning:: The API is only meant to be used by plugins authors.

.. autoclass:: rez_pip.pip.T

.. autoclass:: rez_pip.pip.DownloadInfo
   :members:

.. autoclass:: rez_pip.pip.Metadata
   :members:
   :undoc-members:

.. autoclass:: rez_pip.pip.PackageInfo
   :members:

.. autoclass:: rez_pip.pip.PackageGroup
   :members:
   :show-inheritance:

.. autoclass:: rez_pip.pip.DownloadedArtifact
   :members:

.. autoclass:: rez_pip.plugins.CleanupAction
   :members:
